pub type FxHashSet<V> = HashSet<V, FxBuildHasher>;Available on crate feature
std only.Expand description
Type alias for a hash set that uses the Fx hashing algorithm.
Aliased Type
pub struct FxHashSet<V> { /* private fields */ }pub type FxHashSet<V> = HashSet<V, FxBuildHasher>;std only.Type alias for a hash set that uses the Fx hashing algorithm.
pub struct FxHashSet<V> { /* private fields */ }